# 0.4.3
* fix default value for "double" numbers
* remove size literals (L/D) in python code
* improve PAP naming (thanks knipknap)

# 0.4.2
* add resources for year 2020 (thanks csarn)
* fix README python example (thanks csarn)

# 0.4.1
* Fixed CLI examples in README

# 0.4.0
* Added PAP for 2018 and 2019
* Fixed BMF URIs
* Added "version" cli option 

# 0.3.2
* Make pypi happy

# 0.3.1
* Added support for 2017 PAP
* Fixed unary operator conversion
* Replaced Decimal.\_rescale with Decimal.quantize to
  remain python3 compliant

# 0.3.0
* Added JS support
* Refactored generators for java-like languages
* Cleaned up a bit to satisfy pylint

# 0.2.0
* Refactored writers to generators
* Added basic tests
* Added BigDecimal PHP proxy class

# 0.1.1
* Fixed packaging issues for README.md and CHANGES.md

# 0.1.0
* Initial version
